```{toctree}
---
maxdepth: 2
hidden: true
---

self
converters
usage
structuring
unstructuring
customizing
strategies
validation
preconf
unions
history
benchmarking
contributing
API <modules>
```

```{include} ../README.md

```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
